.. Abjad documentation master file, created by
    sphinx-quickstart on Tue Apr 14 22:09:19 2009.
    You can adapt this file completely to your liking, 
    but it should at least contain the root `toctree` directive.

Welcome to Abjad (|release|)
=============================

Abjad helps composers build up complex pieces of music notation
in an iterative and incremental way. 
Use Abjad to create a symbolic representation of all the notes, 
rests, staves, tuplets, beams and slurs in any score.
Because Abjad extends the Python programming language,
you can use Abjad to make systematic changes to your music as you work.
And because Abjad wraps the powerful LilyPond music notation package,
you can use Abjad to control the typographic details of the symbols on the page.

.. image:: chapters/examples/bartok/images/bartok-final.png


Start here

.. toctree::
    :maxdepth: 1

    chapters/start_here/abjad/index
    chapters/start_here/installation/index
    chapters/start_here/versions/index

Examples

.. toctree::
    :numbered:

    chapters/examples/bartok/index
    chapters/examples/ferneyhough/index
    chapters/examples/ligeti/index
    chapters/examples/mozart/index

Tutorials

.. toctree::
    :numbered:

    chapters/tutorials/lcs/index
    chapters/tutorials/parentage/index
    chapters/tutorials/threads/index
    chapters/tutorials/grobs/index
    chapters/tutorials/understanding_overrides/index
    chapters/tutorials/time_signature_marks/index

Reference manual

.. toctree::
    :numbered:

    chapters/reference_manual/annotations/index
    chapters/reference_manual/articulations/index
    chapters/reference_manual/chords/index
    chapters/reference_manual/containers/index
    chapters/reference_manual/durations/index
    chapters/reference_manual/instrument_marks/index
    chapters/reference_manual/io/index
    chapters/reference_manual/lilypond_command_marks/index
    chapters/reference_manual/lilypond_comments/index
    chapters/reference_manual/lilypond_files/index
    chapters/reference_manual/measures/index
    chapters/reference_manual/notes/index
    chapters/reference_manual/named_chromatic_pitch/index
    chapters/reference_manual/python_basics/index
    chapters/reference_manual/rests/index
    chapters/reference_manual/scores/index
    chapters/reference_manual/spanners/index
    chapters/reference_manual/staves/index
    chapters/reference_manual/tuplets/index
    chapters/reference_manual/voices/index

Developer documentation

.. toctree::
    :numbered:

    chapters/developer_documentation/codebase/index
    chapters/developer_documentation/documentation/index
    chapters/developer_documentation/tests/index
    chapters/developer_documentation/scripts/index
    chapters/developer_documentation/abjad_book/index
    chapters/developer_documentation/timing/index
    chapters/developer_documentation/profiling/index
    chapters/developer_documentation/memory/index
    chapters/developer_documentation/class_attributes/index
    chapters/developer_documentation/slots/index
    chapters/developer_documentation/coding_standards/index

Appendices

.. toctree::
    :numbered:
    :maxdepth: 1

    chapters/appendices/history/index
    chapters/appendices/templates/index
    chapters/appendices/text_alignment/index
    chapters/appendices/bibliography/index

Abjad API
---------

.. toctree::
    :maxdepth: 1

    chapters/api/index
